@@ -13,10 +13,12 @@ import aws_cdk.aws_iam._jsii
 import aws_cdk.aws_kms._jsii
 import aws_cdk.aws_lambda._jsii
 import aws_cdk.core._jsii
+import cdk_iam_floyd._jsii
 import constructs._jsii
-import iam_floyd._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("cdk-ec2-key-pair", "1.4.0", __name__[0:-6], "cdk-ec2-key-pair@1.4.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "cdk-ec2-key-pair", "1.5.0", __name__[0:-6], "cdk-ec2-key-pair@1.5.0.jsii.tgz"
+)
 
 __all__ = [
     "__jsii_assembly__",
